# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-02 04:44
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_outbox_middleware', '0002_outboxrequestlog_request_flagged_duplicate'),
    ]

    operations = [
        migrations.AlterField(
            model_name='outboxrequestlog',
            name='request_uuid',
            field=models.UUIDField(db_index=True),
        ),
    ]
