# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-02 01:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_outbox_middleware', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='outboxrequestlog',
            name='request_flagged_duplicate',
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
    ]
